@@ -612,6 +612,7 @@ class UserForm(forms.ModelForm):
         model = User
 
     def __init__(self, app_field_objs, *args, **kwargs):
+        request = kwargs.pop('request')
         super(UserForm, self).__init__(*args, **kwargs)
 
         del self.fields['groups']
@@ -619,6 +620,13 @@ class UserForm(forms.ModelForm):
         assign_fields(self, app_field_objs)
         self_fields_keys = self.fields.keys()
 
+        is_renewal = 'username' in request.GET
+        if request.user.is_superuser and is_renewal:
+            self_fields_keys.remove('username')
+            self_fields_keys.remove('password')
+            self.fields.pop('username')
+            self.fields.pop('password')
+
         if 'password' in self_fields_keys:
 
             self.fields['password'] = forms.CharField(
